﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.FlowEngine.Notifies;
using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Enums.Order;
using MediatR;

namespace Hotline.Application.Handlers.FlowEngine
{
    public class StartWorkflowHandler : INotificationHandler<StartWorkflowNotify>
    {
        private readonly IOrderDomainService _orderDomainService;

        public StartWorkflowHandler(IOrderDomainService orderDomainService)
        {
            _orderDomainService = orderDomainService;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(StartWorkflowNotify notification, CancellationToken cancellationToken)
        {
            var workflow = notification.Workflow;
            var data = notification.Dto;

            switch (workflow.ModuleCode)
            {
                case WorkflowModuleConsts.OrderManage:
                    await _orderDomainService.OrderManageAsync(EOrderStatus.WaitForSign, notification.FlowAssignType, 
                        false, notification.IsCountersignStart,
                        workflow.ExternalId, workflow.CurrentStepTime, workflow.CurrentStepName,
                        data.Handlers.Select(d => d.Id), cancellationToken);
                    break;
            }
        }
    }
}
